Enum wash_cli::app::AppCliCommand
source · pub enum AppCliCommand {
List(ListCommand),
Get(GetCommand),
Status(StatusCommand),
History(HistoryCommand),
Delete(DeleteCommand),
Put(PutCommand),
Deploy(DeployCommand),
Undeploy(UndeployCommand),
Validate(ValidateCommand),
}Variants
List(ListCommand)
List all applications available within the lattice
Get(GetCommand)
Get the application manifest for a specific version of an application
Status(StatusCommand)
Get the current status of a given application
History(HistoryCommand)
Get the version history of a given application
Delete(DeleteCommand)
Delete an application version
Put(PutCommand)
Create an application version by putting the manifest into the wadm store
Deploy(DeployCommand)
Deploy an application to the lattice
Undeploy(UndeployCommand)
Undeploy an application, removing it from the lattice
Validate(ValidateCommand)
Validate an application manifest