Struct DevCommand

pub struct DevCommand {
    pub nats_opts: NatsOpts,
    pub wasmcloud_opts: WasmcloudOpts,
    pub wadm_opts: WadmOpts,
    pub package_args: CommonPackageArgs,
    pub host_id: Option<ServerId>,
    pub code_dir: Option<PathBuf>,
    pub ignore_dirs: Vec<PathBuf>,
    pub leave_host_running: bool,
    pub manifest_output_dir: Option<PathBuf>,
    pub skip_wit_fetch: bool,
}

Fields

nats_opts: NatsOptswasmcloud_opts: WasmcloudOptswadm_opts: WadmOptspackage_args: CommonPackageArgshost_id: Option<ServerId>

ID of the host to use for wash dev if one is not selected, wash dev will attempt to use the single host in the lattice

code_dir: Option<PathBuf>

Path to code directory

ignore_dirs: Vec<PathBuf>

Directories to ignore when watching for changes. This should be set to directories where generated files are placed, such as target/ or dist/. Can be specified multiple times.

leave_host_running: bool

Whether to leave the host running after dev

manifest_output_dir: Option<PathBuf>

Write generated WADM manifest(s) to a given folder (every time they are generated)

skip_wit_fetch: bool

Skip wit dependency fetching and use only what is currently present in the wit directory (useful for airgapped or disconnected environments)