wash_cli::cmd::up

Struct WasmcloudOpts

source
pub struct WasmcloudOpts {
Show 37 fields pub wasmcloud_version: String, pub lattice: Option<String>, pub host_seed: Option<String>, pub rpc_host: Option<String>, pub rpc_port: Option<u16>, pub rpc_seed: Option<String>, pub rpc_timeout_ms: Option<u64>, pub rpc_jwt: Option<String>, pub rpc_tls: bool, pub rpc_tls_ca_file: Option<PathBuf>, pub rpc_credsfile: Option<PathBuf>, pub ctl_host: Option<String>, pub ctl_port: Option<u16>, pub ctl_seed: Option<String>, pub ctl_jwt: Option<String>, pub ctl_credsfile: Option<PathBuf>, pub ctl_tls: bool, pub ctl_tls_ca_file: Option<PathBuf>, pub cluster_seed: Option<String>, pub cluster_issuers: Option<Vec<String>>, pub provider_delay: u32, pub allow_latest: bool, pub allowed_insecure: Option<Vec<String>>, pub wasmcloud_js_domain: Option<String>, pub config_service_enabled: bool, pub allow_file_load: Option<bool>, pub enable_structured_logging: bool, pub label: Option<Vec<String>>, pub structured_log_level: String, pub enable_ipv6: bool, pub start_only: bool, pub multi_local: bool, pub max_execution_time: u64, pub secrets_topic: Option<String>, pub policy_topic: Option<String>, pub host_log_path: Option<PathBuf>, pub host_path: Option<PathBuf>,
}

Fields

wasmcloud_version: String

wasmCloud host version to download, e.g. v0.55.0. See https://github.com/wasmCloud/wasmcloud/releases for releases

lattice: Option<String>

A unique identifier for a lattice, frequently used within NATS topics to isolate messages among different lattices

host_seed: Option<String>

The seed key (a printable 256-bit Ed25519 private key) used by this host to generate it’s public key

rpc_host: Option<String>

An IP address or DNS name to use to connect to NATS for RPC messages, defaults to the value supplied to –nats-host if not supplied

rpc_port: Option<u16>

A port to use to connect to NATS for RPC messages, defaults to the value supplied to –nats-port if not supplied

rpc_seed: Option<String>

A seed nkey to use to authenticate to NATS for RPC messages

rpc_timeout_ms: Option<u64>

Timeout in milliseconds for all RPC calls

rpc_jwt: Option<String>

A user JWT to use to authenticate to NATS for RPC messages

rpc_tls: bool

Optional flag to enable host communication with a NATS server over TLS for RPC messages

rpc_tls_ca_file: Option<PathBuf>

A TLS CA file to use to authenticate to NATS for RPC messages

rpc_credsfile: Option<PathBuf>

Convenience flag for RPC authentication, internally this parses the JWT and seed from the credsfile

ctl_host: Option<String>

An IP address or DNS name to use to connect to NATS for Control Interface (CTL) messages, defaults to the value supplied to –nats-host if not supplied

ctl_port: Option<u16>

A port to use to connect to NATS for CTL messages, defaults to the value supplied to –nats-port if not supplied

ctl_seed: Option<String>

A seed nkey to use to authenticate to NATS for CTL messages

ctl_jwt: Option<String>

A user JWT to use to authenticate to NATS for CTL messages

ctl_credsfile: Option<PathBuf>

Convenience flag for CTL authentication, internally this parses the JWT and seed from the credsfile

ctl_tls: bool

Optional flag to enable host communication with a NATS server over TLS for CTL messages

ctl_tls_ca_file: Option<PathBuf>

A TLS CA file to use to authenticate to NATS for CTL messages

cluster_seed: Option<String>

The seed key (a printable 256-bit Ed25519 private key) used by this host to sign all invocations

cluster_issuers: Option<Vec<String>>

A comma-delimited list of public keys that can be used as issuers on signed invocations

provider_delay: u32

Delay, in milliseconds, between requesting a provider shut down and forcibly terminating its process

allow_latest: bool

Determines whether OCI images tagged latest are allowed to be pulled from OCI registries and started

allowed_insecure: Option<Vec<String>>

A comma-separated list of OCI hosts to which insecure (non-TLS) connections are allowed

wasmcloud_js_domain: Option<String>

Jetstream domain name, configures a host to properly connect to a NATS supercluster

config_service_enabled: bool

Denotes if a wasmCloud host should issue requests to a config service on startup

allow_file_load: Option<bool>

Denotes if a wasmCloud host should allow starting components from the file system

enable_structured_logging: bool

Enable JSON structured logging from the wasmCloud host

label: Option<Vec<String>>

A label to apply to the host, in the form of key=value. This flag can be repeated to supply multiple labels

structured_log_level: String

Controls the verbosity of JSON structured logs from the wasmCloud host

enable_ipv6: bool

Enables IPV6 addressing for wasmCloud hosts

start_only: bool

If enabled, wasmCloud will not be downloaded if it’s not installed

multi_local: bool

If enabled, allows starting additional wasmCloud hosts on this machine

max_execution_time: u64

Defines the Max Execution time (in ms) that the host runtime will execute for

secrets_topic: Option<String>

If provided, enables interfacing with a secrets backend for secret retrieval over the given topic prefix.

policy_topic: Option<String>

If provided, enables policy checks on start actions and component invocations

host_log_path: Option<PathBuf>

Path to which to log information from the wasmCloud host

host_path: Option<PathBuf>

Path to a binary that should be used to start the wasmCloud host

Implementations

source

impl WasmcloudOpts

source

pub async fn into_ctl_client( self, auction_timeout_ms: Option<u64>, ) -> Result<CtlClient>