Enum WitCommand

pub enum WitCommand {
    Build(BuildArgs),
    Deps(DepsArgs),
    Publish(PublishArgs),
}
Commands for interacting with wit (wash wit)

These commands mirror the wkg wit subcommand, but are adapted for use with wash

Variants



Build(BuildArgs)

Build a WIT package from a directory. By default, this will fetch all dependencies needed and encode them in the WIT package. This will generate a lock file that can be used to fetch the dependencies in the future.



Deps(DepsArgs)

Fetch dependencies for a component.

This will read the package containing the world(s) you have defined in the given wit directory (wit by default). It will then fetch the dependencies and write them to the deps directory along with a lock file. If no lock file exists, it will fetch all dependencies. If a lock file exists, it will fetch any dependencies that are not in the lock file and update the lock file.



Publish(PublishArgs)

Publish a WIT package to a registry. This will automatically infer the package name from the WIT package.