Module ctl

Enums

CtlCliCommand
CtlGetCommand

Functions

claims_table
Helper function to transform a ClaimsList into a table string for printing
get_claims_output
get_host_inventories_output
get_hosts_output
host_inventories_table
Helper function to transform a HostInventory into a table string for printing
hosts_table
Helper function to transform a Host list into a table string for printing
links_table
plugins_table
Helper function to transform a list of plugin metadata into a table string for printing