pub struct EditCommand {
pub name: Option<String>,
pub editor: String,
/* private fields */
}Fields
name: Option<String>Name of the context to edit, if not supplied the user will be prompted to select a context
editor: StringYour terminal text editor of choice. This editor must be present in your $PATH, or an absolute filepath.