pub struct DevCommand {
pub nats_opts: NatsOpts,
pub wasmcloud_opts: WasmcloudOpts,
pub wadm_opts: WadmOpts,
pub host_id: Option<ServerId>,
pub code_dir: Option<PathBuf>,
pub leave_host_running: bool,
pub manifest_output_dir: Option<PathBuf>,
}Fields
nats_opts: NatsOptswasmcloud_opts: WasmcloudOptswadm_opts: WadmOptshost_id: Option<ServerId>ID of the host to use for wash dev
if one is not selected, wash dev will attempt to use the single host in the lattice
code_dir: Option<PathBuf>Path to code directory
leave_host_running: boolWhether to leave the host running after dev
manifest_output_dir: Option<PathBuf>Write generated WADM manifest(s) to a given folder (every time they are generated)