pub struct DownCommand {
pub lattice: String,
pub ctl_host: Option<String>,
pub ctl_port: Option<u16>,
pub ctl_credsfile: Option<PathBuf>,
pub ctl_seed: Option<String>,
pub ctl_jwt: Option<String>,
pub ctl_tls_ca_file: Option<PathBuf>,
pub ctl_tls_first: Option<bool>,
pub host_id: Option<ServerId>,
pub all: bool,
pub purge: PurgeJetstream,
}Fields
lattice: StringA lattice prefix is a unique identifier for a lattice, and is frequently used within NATS topics to isolate messages from different lattices
ctl_host: Option<String>An IP address or DNS name to use to connect to NATS for Control Interface (CTL) messages, defaults to the value supplied to –nats-host if not supplied
ctl_port: Option<u16>A port to use to connect to NATS for CTL messages, defaults to the value supplied to –nats-port if not supplied
ctl_credsfile: Option<PathBuf>Convenience flag for CTL authentication, internally this parses the JWT and seed from the credsfile
ctl_seed: Option<String>A seed nkey to use to authenticate to NATS for CTL messages
ctl_jwt: Option<String>A user JWT to use to authenticate to NATS for CTL messages
ctl_tls_ca_file: Option<PathBuf>A TLS CA file to use to authenticate to NATS for CTL messages
ctl_tls_first: Option<bool>Perform TLS handshake before expecting the server greeting
host_id: Option<ServerId>all: boolShutdown all hosts running locally if launched with –multi-local
purge: PurgeJetstreamPurge NATS Jetstream storage and streams that persist when wasmCloud is stopped