pub async fn handle_insert(
cmd: InsertCommand,
output_kind: OutputKind,
) -> Result<CommandOutput>Expand description
Loads a provider archive and attempts to insert an additional provider into it
pub async fn handle_insert(
cmd: InsertCommand,
output_kind: OutputKind,
) -> Result<CommandOutput>Loads a provider archive and attempts to insert an additional provider into it