Struct PluginInstallCommand

pub struct PluginInstallCommand {
    pub oci_auth: AuthOpts,
    pub url: String,
    pub digest: Option<String>,
    pub allow_latest: bool,
    pub update: bool,
    pub opts: PluginCommonOpts,
}

Fields

oci_auth: AuthOptsurl: String

URL of the plugin to install. Can be a file://, http://, https://, or oci:// URL.

digest: Option<String>

Digest to verify plugin against. For OCI manifests, this is the digest format used in the manifest. For other types of plugins, this is the SHA256 digest of the plugin binary.

allow_latest: bool

Allow latest artifact tags (if pulling from OCI registry)

update: bool

Whether or not to update the plugin if it is already installed. Defaults to false

opts: PluginCommonOpts