Styling for wash CLI
These are originally the same styles used by clap_cargo as of v0.14.1 see: https://docs.rs/clap-cargo/0.14.1/src/clap_cargo/style.rs.html
Styling for wash CLI
These are originally the same styles used by clap_cargo as of v0.14.1 see: https://docs.rs/clap-cargo/0.14.1/src/clap_cargo/style.rs.html