pub struct NatsOpts {
pub nats_credsfile: Option<PathBuf>,
pub nats_configfile: Option<PathBuf>,
pub nats_remote_url: Option<String>,
pub connect_only: bool,
pub nats_version: String,
pub nats_host: Option<String>,
pub nats_port: Option<u16>,
pub nats_websocket_port: u16,
pub nats_js_domain: Option<String>,
}Fields
nats_credsfile: Option<PathBuf>Optional path to a NATS credentials file to authenticate and extend existing NATS infrastructure.
nats_configfile: Option<PathBuf>Optional path to a NATS config file NOTE: If your configuration changes the address or port to listen on from 0.0.0.0:4222, ensure you set –nats-host and –nats-port
nats_remote_url: Option<String>Optional remote URL of existing NATS infrastructure to extend.
connect_only: boolIf a connection can’t be established, exit and don’t start a NATS server. Will be ignored if a remote_url and credsfile are specified
nats_version: StringNATS server version to download, e.g. v2.10.7. See https://github.com/nats-io/nats-server/releases/ for releases
nats_host: Option<String>NATS server host to connect to
nats_port: Option<u16>NATS server port to connect to. This will be used as the NATS listen port if --nats-connect-only isn’t set
nats_websocket_port: u16NATS websocket port to use. TLS is not supported. This is required for the wash ui to connect from localhost
nats_js_domain: Option<String>NATS Server Jetstream domain for extending superclusters