pub struct WadmOpts {
pub wadm_version: String,
pub disable_wadm: bool,
pub wadm_js_domain: Option<String>,
pub wadm_manifest: Option<PathBuf>,
}Fields
wadm_version: Stringwadm version to download, e.g. v0.4.0. See https://github.com/wasmCloud/wadm/releases for releases
disable_wadm: boolIf enabled, wadm will not be downloaded or run as a part of the up command
wadm_js_domain: Option<String>The JetStream domain to use for wadm
wadm_manifest: Option<PathBuf>The path to a wadm application manifest to run while the host is up