Module util

Functions

configure_table_style
default_timeout_ms
ensure_plugin_dir
Ensure that the given plugin directory exists or return the default plugin dir path
extract_arg_value
Returns value from an argument that may be a file path or the value itself
format_optional
json_str_to_msgpack_bytes
Transform a json string (e.g. “{“hello”: “world”}“) into msgpack bytes
load_plugins
Helper for loading plugins from the given directory
msgpack_to_json_val
transform msgpack bytes into json