pub struct BuildArgs {
pub dir: PathBuf,
pub output_file: Option<PathBuf>,
pub common: CommonPackageArgs,
/* private fields */
}Fields
dir: PathBufThe directory containing the WIT files to build.
output_file: Option<PathBuf>The name of the file that should be written. This can also be a full path. Defaults to the current directory with the name of the package
common: CommonPackageArgsImplementations