Struct wash_cli::build::BuildCommand
source · pub struct BuildCommand {
pub keys_directory: Option<PathBuf>,
pub issuer: Option<String>,
pub subject: Option<String>,
pub disable_keygen: bool,
pub build_only: bool,
pub sign_only: bool,
/* private fields */
}Expand description
Build (and sign) a wasmCloud component, provider, or interface
Fields
keys_directory: Option<PathBuf>Location of key files for signing. Defaults to $WASH_KEYS ($HOME/.wash/keys)
issuer: Option<String>Path to issuer seed key (account). If this flag is not provided, the seed will be sourced from $WASH_KEYS ($HOME/.wash/keys) or generated for you if it cannot be found.
subject: Option<String>Path to subject seed key (module or service). If this flag is not provided, the seed will be sourced from $WASH_KEYS ($HOME/.wash/keys) or generated for you if it cannot be found.
disable_keygen: boolDisables autogeneration of keys if seed(s) are not provided
build_only: boolSkip signing the artifact and only use the native toolchain to build
sign_only: boolSkip building the artifact and only use configuration to sign