pub struct PluginInstallCommand {
pub oci_auth: AuthOpts,
pub url: String,
pub digest: Option<String>,
pub allow_latest: bool,
pub update: bool,
pub opts: PluginCommonOpts,
}Fields
oci_auth: AuthOptsurl: StringURL of the plugin to install. Can be a file://, http://, https://, or oci:// URL.
digest: Option<String>Digest to verify plugin against. For OCI manifests, this is the digest format used in the manifest. For other types of plugins, this is the SHA256 digest of the plugin binary.
allow_latest: boolAllow latest artifact tags (if pulling from OCI registry)
update: boolWhether or not to update the plugin if it is already installed. Defaults to false
opts: PluginCommonOptsTrait Implementations
Sourceimpl Args for PluginInstallCommand
impl Args for PluginInstallCommand
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Clone for PluginInstallCommand
impl Clone for PluginInstallCommand
Sourcefn clone(&self) -> PluginInstallCommand
fn clone(&self) -> PluginInstallCommand
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PluginInstallCommand
impl Debug for PluginInstallCommand
Sourceimpl FromArgMatches for PluginInstallCommand
impl FromArgMatches for PluginInstallCommand
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for PluginInstallCommand
impl Parser for PluginInstallCommand
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)