Functions
- configure_
table_ style - default_
timeout_ ms - ensure_
plugin_ dir - Ensure that the given plugin directory exists or return the default plugin dir path
- extract_
arg_ value - Returns value from an argument that may be a file path or the value itself
- format_
optional - json_
str_ to_ msgpack_ bytes - Transform a json string (e.g. “{“hello”: “world”}“) into msgpack bytes
- load_
plugins - Helper for loading plugins from the given directory
- msgpack_
to_ json_ val - transform msgpack bytes into json