Functions
- Ensure that the given plugin directory exists or return the default plugin dir path
- Returns value from an argument that may be a file path or the value itself
- Transform a json string (e.g. “{“hello”: “world”}“) into msgpack bytes
- Helper for loading plugins from the given directory
- transform msgpack bytes into json